# Faceblur
_Faceblur_ is a Python library and command-line tool to obfuscate
faces from photos and videos via blurring them.

It uses the _av_ package to access _FFmpeg_ functionality, and _pymediainfo_
to obtain file and stream metadata, that is not yet available through _av_
(even though it _is_ available in _FFmpeg_).

## License
Licensed under BSD 3-Clause.

## Copyright
Copyright (C) 2025 Simona Dimitrova
